# ModelBuilder

```{eval-rst}
.. autoclass:: openpkpd.api.model_builder.ModelBuilder
   :members:
   :special-members: __init__
   :undoc-members: False
```

```{eval-rst}
.. autoclass:: openpkpd.api.model_builder.BuiltModel
   :members:
   :undoc-members: False
```
